@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.617-15-gea47162e
+package JSON::Schema::Modern; # git description: v0.618-6-g02532570
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema using a JSON Schema
 # KEYWORDS: JSON Schema validator data validation structure specification
 
-our $VERSION = '0.618';
+our $VERSION = '0.619';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -122,6 +122,8 @@ has _format_validations => (
 sub _get_format_validation ($self, $format) { ($self->{_format_validations}//{})->{$format} }
 
 sub add_format_validation ($self, $format, $definition) {
+  return if exists(($self->{_format_validations}//{})->{$format});
+
   $definition = { type => 'string', sub => $definition } if not is_plain_hashref($definition);
   $format_type->({ $format => $definition });
 
@@ -290,22 +292,22 @@ sub evaluate_json_string ($self, $json_data, $schema, $config_override = {}) {
 # Returns the internal $state object accumulated during the traversal.
 sub traverse ($self, $schema_reference, $config_override = {}) {
   my %overrides = %$config_override;
-  delete @overrides{qw(callbacks initial_schema_uri metaschema_uri traversed_schema_path specification_version)};
+  delete @overrides{qw(callbacks initial_schema_uri metaschema_uri traversed_keyword_path specification_version)};
   croak join(', ', sort keys %overrides), ' not supported as a config override in traverse'
     if keys %overrides;
 
   # Note: the starting position is not guaranteed to be at the root of the $document,
   # nor is the fragment portion of this uri necessarily empty
   my $initial_uri = Mojo::URL->new($config_override->{initial_schema_uri} // ());
-  my $initial_path = $config_override->{traversed_schema_path} // '';
+  my $initial_path = $config_override->{traversed_keyword_path} // '';
   my $spec_version = $config_override->{specification_version} // $self->specification_version // SPECIFICATION_VERSION_DEFAULT;
 
-  croak 'traversed_schema_path must be a json pointer' if $initial_path !~ m{^(?:/|$)};
+  croak 'traversed_keyword_path must be a json pointer' if $initial_path !~ m{^(?:/|$)};
 
   if (length(my $uri_path = $initial_uri->fragment)) {
     croak 'initial_schema_uri fragment must be a json pointer' if $uri_path !~ m{^/};
 
-    croak 'traversed_schema_path does not match initial_schema_uri path fragment'
+    croak 'traversed_keyword_path does not match initial_schema_uri path fragment'
       if substr($initial_path, -length($uri_path)) ne $uri_path;
   }
 
@@ -313,8 +315,8 @@ sub traverse ($self, $schema_reference, $config_override = {}) {
     depth => 0,
     data_path => '',                        # this never changes since we don't have an instance yet
     initial_schema_uri => $initial_uri,     # the canonical URI as of the start of this method or last $id
-    traversed_schema_path => $initial_path, # the accumulated traversal path as of the start or last $id
-    schema_path => '',                      # the rest of the path, since the start of this method or last $id
+    traversed_keyword_path => $initial_path, # the accumulated traversal path as of the start or last $id
+    keyword_path => '',                      # the rest of the path, since the start of this method or last $id
     specification_version => $spec_version,
     errors => [],
     identifiers => {},
@@ -375,15 +377,15 @@ sub evaluate ($self, $data, $schema_reference, $config_override = {}) {
   croak 'evaluate called in void context' if not defined wantarray;
 
   my %overrides = %$config_override;
-  delete @overrides{qw(validate_formats validate_content_schemas short_circuit collect_annotations scalarref_booleans stringy_numbers strict callbacks effective_base_uri data_path traversed_schema_path _strict_schema_data)};
+  delete @overrides{qw(validate_formats validate_content_schemas short_circuit collect_annotations scalarref_booleans stringy_numbers strict callbacks effective_base_uri data_path traversed_keyword_path _strict_schema_data)};
   croak join(', ', sort keys %overrides), ' not supported as a config override in evaluate'
     if keys %overrides;
 
   my $state = {
     data_path => $config_override->{data_path} // '',
-    traversed_schema_path => $config_override->{traversed_schema_path} // '', # the accumulated path as of the start of evaluation or last $id or $ref
+    traversed_keyword_path => $config_override->{traversed_keyword_path} // '', # the accumulated path as of the start of evaluation or last $id or $ref
     initial_schema_uri => Mojo::URL->new,   # the canonical URI as of the start of evaluation or last $id or $ref
-    schema_path => '',                  # the rest of the path, since the start of evaluation or last $id or $ref
+    keyword_path => '',                  # the rest of the path, since the start of evaluation or last $id or $ref
     errors => [],
     depth => 0,
   };
@@ -582,7 +584,7 @@ sub _traverse_subschema ($self, $schema, $state) {
   return E($state, 'EXCEPTION: maximum traversal depth (%d) exceeded', $self->max_traversal_depth)
     if $state->{depth}++ > $self->max_traversal_depth;
 
-  push $state->{subschemas}->@*, $state->{traversed_schema_path}.$state->{schema_path};
+  push $state->{subschemas}->@*, $state->{traversed_keyword_path}.$state->{keyword_path};
 
   my $schema_type = get_type($schema);
   return 1 if $schema_type eq 'boolean';
@@ -697,7 +699,7 @@ sub _eval_subschema ($self, $data, $schema, $state) {
   # find all schema locations in effect at this data path + uri combination
   # if any of them are absolute prefix of this schema location, we are in a loop.
   my $canonical_uri = canonical_uri($state);
-  my $schema_location = $state->{traversed_schema_path}.$state->{schema_path};
+  my $schema_location = $state->{traversed_keyword_path}.$state->{keyword_path};
   {
     use autovivification qw(fetch store);
     abort($state, 'EXCEPTION: infinite loop detected (same location evaluated twice)')
@@ -975,13 +977,13 @@ sub _fetch_vocabulary_data ($self, $state, $schema_info) {
 
   foreach my $uri (sort keys $schema_info->{schema}{'$vocabulary'}->%*) {
     my $class_info = $self->_get_vocabulary_class($uri);
-    $valid = E({ %$state, _schema_path_suffix => $uri }, '"%s" is not a known vocabulary', $uri), next
+    $valid = E({ %$state, _keyword_path_suffix => $uri }, '"%s" is not a known vocabulary', $uri), next
       if $schema_info->{schema}{'$vocabulary'}{$uri} and not $class_info;
 
     next if not $class_info;  # vocabulary is not known, but marked as false in the metaschema
 
     my ($spec_version, $class) = @$class_info;
-    $valid = E({ %$state, _schema_path_suffix => $uri }, '"%s" uses %s, but the metaschema itself uses %s',
+    $valid = E({ %$state, _keyword_path_suffix => $uri }, '"%s" uses %s, but the metaschema itself uses %s',
         $uri, $spec_version, $schema_info->{specification_version}), next
       if $spec_version ne $schema_info->{specification_version};
 
@@ -1292,7 +1294,7 @@ JSON::Schema::Modern - Validate data against a schema using a JSON Schema
 
 =head1 VERSION
 
-version 0.618
+version 0.619
 
 =head1 SYNOPSIS
 
@@ -1542,7 +1544,7 @@ C<data_path>: adjusts the effective path of the data instance as of the start of
 
 =item *
 
-C<traversed_schema_path>: adjusts the accumulated path as of the start of evaluation (or last C<$id> or C<$ref>)
+C<traversed_keyword_path>: adjusts the accumulated path as of the start of evaluation (or last C<$id> or C<$ref>)
 
 =item *
 
@@ -1596,7 +1598,7 @@ C<data_path>: adjusts the effective path of the data instance as of the start of
 
 =item *
 
-C<traversed_schema_path>: adjusts the accumulated path as of the start of evaluation (or last C<$id> or C<$ref>)
+C<traversed_keyword_path>: adjusts the accumulated path as of the start of evaluation (or last C<$id> or C<$ref>)
 
 =item *
 
@@ -1647,7 +1649,7 @@ applications that contain embedded JSON Schemas):
 
 =item *
 
-C<traversed_schema_path>: adjusts the accumulated path as of the start of evaluation (or last C<$id> or C<$ref>)
+C<traversed_keyword_path>: adjusts the accumulated path as of the start of evaluation (or last C<$id> or C<$ref>)
 
 =item *
 
@@ -1743,7 +1745,7 @@ do not apply arithmetic operators to it -- or subsequent type checks on this val
 See L<https://spec.openapis.org/registry/format/> for a registry of known and useful formats; for
 compatibility reasons, avoid defining a format listed here with different semantics.
 
-Format definitions can be overridden with a new call to C<add_format_validation>.
+Format definitions cannot be overridden with a new definition.
 
 =head2 add_vocabulary
 
