@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Utilities;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Internal utilities for JSON::Schema::Modern
 
-our $VERSION = '0.618';
+our $VERSION = '0.619';
 
 use 5.020;
 use strictures 2;
@@ -312,12 +312,12 @@ sub local_annotations ($state) {
 
 # shorthand for finding the current uri of the present schema location
 # ensure that this code is kept consistent with the absolute_keyword_location builder in ResultNode
-# Note that this may not be canonical if schema_path has not yet been reset via the processing of a
+# Note that this may not be canonical if keyword_path has not yet been reset via the processing of a
 # local identifier keyword (e.g. '$id').
 sub canonical_uri ($state, @extra_path) {
-  return $state->{initial_schema_uri} if not @extra_path and not length($state->{schema_path});
+  return $state->{initial_schema_uri} if not @extra_path and not length($state->{keyword_path});
   my $uri = $state->{initial_schema_uri}->clone;
-  my $fragment = ($uri->fragment//'').(@extra_path ? jsonp($state->{schema_path}, @extra_path) : $state->{schema_path});
+  my $fragment = ($uri->fragment//'').(@extra_path ? jsonp($state->{keyword_path}, @extra_path) : $state->{keyword_path});
   undef $fragment if not length($fragment);
   $uri->fragment($fragment);
   $uri;
@@ -329,9 +329,9 @@ sub canonical_uri ($state, @extra_path) {
 # - effective_base_uri (optional)
 # - keyword (optional)
 # - data_path
-# - traversed_schema_path
-# - schema_path
-# - _schema_path_suffix (optional)
+# - traversed_keyword_path
+# - keyword_path
+# - _keyword_path_suffix (optional)
 # - errors
 # - exception (optional; set by abort())
 # - recommended_response (optional)
@@ -343,15 +343,15 @@ sub E ($state, $error_string, @args) {
   croak 'E called in void context' if not defined wantarray;
 
   # sometimes the keyword shouldn't be at the very end of the schema path
-  my $sps = delete $state->{_schema_path_suffix};
-  my @schema_path_suffix = defined $sps && is_plain_arrayref($sps) ? $sps->@* : $sps//();
+  my $sps = delete $state->{_keyword_path_suffix};
+  my @keyword_path_suffix = defined $sps && is_plain_arrayref($sps) ? $sps->@* : $sps//();
 
   # we store the absolute uri in unresolved form until needed,
   # and perform the rest of the calculations later.
-  my $uri = [ $state->@{qw(initial_schema_uri schema_path)}, $state->{keyword}//(), @schema_path_suffix, $state->{effective_base_uri} ];
+  my $uri = [ $state->@{qw(initial_schema_uri keyword_path)}, $state->{keyword}//(), @keyword_path_suffix, $state->{effective_base_uri} ];
 
-  my $keyword_location = $state->{traversed_schema_path}
-    .jsonp($state->@{qw(schema_path keyword)}, @schema_path_suffix);
+  my $keyword_location = $state->{traversed_keyword_path}
+    .jsonp($state->@{qw(keyword_path keyword)}, @keyword_path_suffix);
 
   require JSON::Schema::Modern::Error;
   push $state->{errors}->@*, JSON::Schema::Modern::Error->new(
@@ -375,12 +375,10 @@ sub E ($state, $error_string, @args) {
 # - initial_schema_uri
 # - keyword (mandatory)
 # - data_path
-# - traversed_schema_path
-# - schema_path
-# - _schema_path_suffix (optional)
+# - traversed_keyword_path
+# - keyword_path
 # - annotations
 # - collect_annotations
-# - specification_version
 # - _unknown (boolean)
 # - depth
 sub A ($state, $annotation) {
@@ -388,9 +386,9 @@ sub A ($state, $annotation) {
 
   # we store the absolute uri in unresolved form until needed,
   # and perform the rest of the calculations later.
-  my $uri = [ $state->@{qw(initial_schema_uri schema_path keyword effective_base_uri)} ];
+  my $uri = [ $state->@{qw(initial_schema_uri keyword_path keyword effective_base_uri)} ];
 
-  my $keyword_location = $state->{traversed_schema_path}.jsonp($state->@{qw(schema_path keyword)});
+  my $keyword_location = $state->{traversed_keyword_path}.jsonp($state->@{qw(keyword_path keyword)});
 
   push $state->{annotations}->@*, {
     depth => $state->{depth} // 0,
@@ -445,7 +443,7 @@ sub assert_uri_reference ($state, $schema) {
   croak 'assert_uri_reference called in void context' if not defined wantarray;
 
   my $string = $schema->{$state->{keyword}};
-  return E($state, '%s value is not a valid URI reference', $state->{keyword})
+  return E($state, '%s value is not a valid uri-reference', $state->{keyword})
     # see also uri-reference format sub
     if fc(Mojo::URL->new($string)->to_unsafe_string) ne fc($string)
       or $string =~ /[^[:ascii:]]/            # ascii characters only
@@ -511,7 +509,7 @@ JSON::Schema::Modern::Utilities - Internal utilities for JSON::Schema::Modern
 
 =head1 VERSION
 
-version 0.618
+version 0.619
 
 =head1 SYNOPSIS
 
