@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Content;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Content vocabulary
 
-our $VERSION = '0.618';
+our $VERSION = '0.619';
 
 use 5.020;
 use Moo;
@@ -104,7 +104,7 @@ sub _eval_keyword_contentSchema ($class, $data, $schema, $state) {
     return 1 if not exists $state->{_content_ref};  # contentMediaType failed to decode the content
     return E($state, 'subschema is not valid')
       if not $class->eval($state->{_content_ref}->$*, $schema->{contentSchema},
-        { %$state, schema_path => $state->{schema_path}.'/contentSchema' });
+        { %$state, keyword_path => $state->{keyword_path}.'/contentSchema' });
   }
 
   return A($state, is_ref($schema->{contentSchema}) ? dclone($schema->{contentSchema}) : $schema->{contentSchema});
@@ -124,7 +124,7 @@ JSON::Schema::Modern::Vocabulary::Content - Implementation of the JSON Schema Co
 
 =head1 VERSION
 
-version 0.618
+version 0.619
 
 =head1 DESCRIPTION
 
